@@ -1,12 +1,13 @@
 # Declare our package
 package POE::Component::Server::SimpleHTTP::Connection;
-$POE::Component::Server::SimpleHTTP::Connection::VERSION = '2.26';
+$POE::Component::Server::SimpleHTTP::Connection::VERSION = '2.28';
 #ABSTRACT: Stores connection information for SimpleHTTP
 
 use strict;
 use warnings;
 
-use Socket qw( inet_ntoa unpack_sockaddr_in );
+use Socket (qw( AF_INET AF_INET6 AF_UNIX inet_ntop sockaddr_family
+   unpack_sockaddr_in unpack_sockaddr_in6 unpack_sockaddr_un ));
 use POE;
 
 use Moose;
@@ -69,13 +70,14 @@ sub BUILDARGS {
    my $socket = shift;
 
    eval {
-      ( $self->{'remote_port'}, $self->{'remote_addr'} ) =
-        unpack_sockaddr_in( getpeername($socket) );
-      $self->{'remote_ip'} = inet_ntoa( $self->{'remote_addr'} );
+      my $family;
+      ( $family, $self->{'remote_port'}, $self->{'remote_addr'},
+         $self->{'remote_ip'}
+      ) = $class->get_sockaddr_info( getpeername($socket) );
 
-      ( $self->{'local_port'}, $self->{'local_addr'} ) =
-        unpack_sockaddr_in( getsockname($socket) );
-      $self->{'local_ip'} = inet_ntoa( $self->{'local_addr'} );
+      ( $family, $self->{'local_port'}, $self->{'local_addr'},
+         $self->{'local_ip'}
+      ) = $class->get_sockaddr_info( getsockname($socket) );
    };
 
    if ($@) {
@@ -105,6 +107,29 @@ sub DEMOLISH {
    }
 }
 
+sub get_sockaddr_info {
+   my $class = shift;
+   my $sockaddr = shift;
+
+   my $family = sockaddr_family( $sockaddr );
+   my ( $port, $address, $straddress );
+   if ( $family == AF_INET ) {
+      ( $port, $address ) = unpack_sockaddr_in( $sockaddr );
+      $straddress = inet_ntop( $family, $address );
+   } elsif ( $family == AF_INET6 ) {
+      ( $port, $address ) = unpack_sockaddr_in6( $sockaddr );
+      $straddress = inet_ntop( $family, $address );
+   } elsif ( $family == AF_UNIX ) {
+      $address = unpack_sockaddr_un( $sockaddr );
+      $straddress = $address // '<local>';
+      $port = undef;
+   } else {
+      $address = $port = undef;
+      $straddress = '<unknown>';
+   }
+   return ( $family, $address, $port, $straddress );
+}
+
 no Moose;
 
 __PACKAGE__->meta->make_immutable;
@@ -124,7 +149,7 @@ POE::Component::Server::SimpleHTTP::Connection - Stores connection information f
 
 =head1 VERSION
 
-version 2.26
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -142,11 +167,11 @@ version 2.26
 
 	my $connection = POE::Component::Server::SimpleHTTP::Connection->new( $socket );
 
-	$connection->remote_ip();	# Returns remote ip in dotted quad format ( 1.1.1.1 )
+	$connection->remote_ip();	# Returns remote address as a string ( 1.1.1.1 or 2000::1 )
 	$connection->remote_port();	# Returns remote port
 	$connection->remote_addr();	# Returns true remote address, consult the L<Socket> POD
 	$connection->local_addr();	# Returns true local address, same as above
-	$connection->local_ip();	# Returns local ip in dotted quad format ( 1.1.1.1 )
+	$connection->local_ip();	# Returns remote address as a string ( 1.1.1.1 or 2000::1 )
 	$connection->local_port();	# Returns local port
 	$connection->dead();		# Returns a boolean value whether the socket is closed or not
 	$connection->ssl();		# Returns a boolean value whether the socket is SSLified or not
@@ -157,7 +182,7 @@ version 2.26
 
 Nothing.
 
-=for Pod::Coverage DEMOLISH
+=for Pod::Coverage DEMOLISH get_sockaddr_info
 
 =head1 SEE ALSO
 
@@ -170,7 +195,7 @@ Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
+This software is copyright (c) 2018 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
